<?php get_header(); ?>

<div class="container" style="padding: 60px 20px; max-width: 900px;">
    <?php while ( have_posts() ) : the_post(); ?>
        <article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
            <?php if ( has_post_thumbnail() ) : ?>
                <div style="border-radius:12px;overflow:hidden;margin-bottom:32px;">
                    <?php the_post_thumbnail('large', ['style' => 'width:100%;height:400px;object-fit:cover;']); ?>
                </div>
            <?php endif; ?>
            <h1 style="margin-bottom:16px;"><?php the_title(); ?></h1>
            <p style="color:#999;margin-bottom:32px;font-size:0.9rem;">
                <?php echo get_the_date(); ?> door <?php the_author(); ?>
            </p>
            <div class="entry-content">
                <?php the_content(); ?>
            </div>
        </article>
    <?php endwhile; ?>
</div>

<?php get_footer(); ?>
