<?php get_header(); ?>

<div class="container" style="text-align:center;padding:100px 20px;">
    <div style="font-size:6rem;margin-bottom:20px;">🔍</div>
    <h1>Pagina niet gevonden</h1>
    <p style="font-size:1.1rem;margin:16px 0 32px;">De pagina die je zoekt bestaat niet of is verplaatst.</p>
    <a href="<?php echo home_url('/'); ?>" class="btn btn-primary">← Terug naar Home</a>
    <br><br>
    <a href="<?php echo home_url('/shop/'); ?>" class="btn btn-outline">Bekijk onze Shop</a>
</div>

<?php get_footer(); ?>
