<?php get_header(); ?>

<div class="container" style="padding: 60px 20px;">
    <?php if ( have_posts() ) : ?>
        <div class="section-header">
            <h1><?php single_cat_title( '', true ) ?: bloginfo('name'); ?></h1>
        </div>
        <div class="products-grid">
            <?php while ( have_posts() ) : the_post(); ?>
                <div class="product-card">
                    <?php if ( has_post_thumbnail() ) : ?>
                        <div class="product-card-image">
                            <?php the_post_thumbnail('medium'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="product-card-body">
                        <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                        <p><?php the_excerpt(); ?></p>
                    </div>
                    <div class="product-card-footer">
                        <a href="<?php the_permalink(); ?>" class="btn btn-primary">Lees meer →</a>
                    </div>
                </div>
            <?php endwhile; ?>
        </div>
        <div style="text-align:center;margin-top:40px;">
            <?php the_posts_pagination(); ?>
        </div>
    <?php else : ?>
        <div style="text-align:center;padding:80px 0;">
            <h2>Geen inhoud gevonden</h2>
            <p>Probeer een andere pagina of ga terug naar de <a href="<?php echo home_url('/'); ?>">homepage</a>.</p>
        </div>
    <?php endif; ?>
</div>

<?php get_footer(); ?>
