<?php
/**
 * WooCommerce Template Override
 * Zorgt dat WooCommerce pagina's de juiste header/footer krijgen
 */

get_header();
?>

<div class="container" style="padding: 50px 20px;">
    <?php do_action('woocommerce_before_main_content'); ?>
    <?php woocommerce_content(); ?>
    <?php do_action('woocommerce_after_main_content'); ?>
</div>

<?php get_footer(); ?>
