</div><!-- #page-content -->

<footer class="site-footer">
    <div class="container">
        <div class="footer-grid">
            <!-- Brand -->
            <div class="footer-brand">
                <?php if ( has_custom_logo() ) :
                    the_custom_logo();
                else : ?>
                    <span class="site-logo-text"><?php bloginfo('name'); ?></span>
                <?php endif; ?>
                <p><?php echo esc_html( get_bloginfo('description') ?: 'Duurzame producten voor een beter thuis. Kwaliteit die je kunt vertrouwen, direct aan je deur bezorgd.' ); ?></p>
                <div class="footer-social">
                    <a href="#" aria-label="Facebook">📘</a>
                    <a href="#" aria-label="Instagram">📷</a>
                    <a href="#" aria-label="Twitter">🐦</a>
                    <a href="#" aria-label="LinkedIn">💼</a>
                    <a href="#" aria-label="YouTube">▶️</a>
                    <a href="#" aria-label="Pinterest">📌</a>
                </div>
            </div>

            <!-- About -->
            <div class="footer-col">
                <h4><?php _e('Over Ons', 'earthpure'); ?></h4>
                <ul>
                    <li><a href="<?php echo home_url('/team/'); ?>"><?php _e('Team', 'earthpure'); ?></a></li>
                    <li><a href="<?php echo home_url('/history/'); ?>"><?php _e('Geschiedenis', 'earthpure'); ?></a></li>
                    <li><a href="<?php echo home_url('/careers/'); ?>"><?php _e('Vacatures', 'earthpure'); ?></a></li>
                </ul>
            </div>

            <!-- Privacy -->
            <div class="footer-col">
                <h4><?php _e('Privacy', 'earthpure'); ?></h4>
                <ul>
                    <li><a href="<?php echo home_url('/privacy-policy/'); ?>"><?php _e('Privacybeleid', 'earthpure'); ?></a></li>
                    <li><a href="<?php echo home_url('/terms/'); ?>"><?php _e('Algemene Voorwaarden', 'earthpure'); ?></a></li>
                    <li><a href="<?php echo home_url('/contact/'); ?>"><?php _e('Contact', 'earthpure'); ?></a></li>
                </ul>
            </div>

            <!-- Contact -->
            <div class="footer-col">
                <h4><?php _e('Contact', 'earthpure'); ?></h4>
                <div class="footer-contact-item">
                    <span class="icon">📍</span>
                    <span><?php echo esc_html( ep_get('address', '351 Grand Blvd') ); ?></span>
                </div>
                <div class="footer-contact-item">
                    <span class="icon">📞</span>
                    <a href="tel:<?php echo esc_attr( ep_get('phone', '+12345678') ); ?>"><?php echo esc_html( ep_get('phone', '+1 234 567 890') ); ?></a>
                </div>
                <div class="footer-contact-item">
                    <span class="icon">✉️</span>
                    <a href="mailto:<?php echo esc_attr( ep_get('email', 'info@earthpure.net') ); ?>"><?php echo esc_html( ep_get('email', 'info@earthpure.net') ); ?></a>
                </div>
                <div class="footer-contact-item">
                    <span class="icon">🕐</span>
                    <span><?php _e('Altijd bereikbaar', 'earthpure'); ?></span>
                </div>
            </div>
        </div>
    </div>

    <div class="container">
        <div class="footer-bottom">
            <span>© <?php echo date('Y'); ?> <?php bloginfo('name'); ?>. <?php _e('Alle rechten voorbehouden.', 'earthpure'); ?></span>
            <span><?php _e('Gebouwd met', 'earthpure'); ?> ❤️ <?php _e('op WordPress', 'earthpure'); ?></span>
        </div>
    </div>
</footer>

<?php wp_footer(); ?>
</body>
</html>
