/* EarthPure Setup Wizard - Admin Styles */
* { box-sizing: border-box; }

body.wp-admin { background: #f0f4f0 !important; }

#epw-wizard {
    display: flex;
    min-height: 100vh;
    margin: -32px -20px 0 -20px;
    font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
}

/* ========================
   SIDEBAR
   ======================== */
.epw-sidebar {
    width: 280px;
    flex-shrink: 0;
    background: linear-gradient(160deg, #1B5E20 0%, #2E7D32 50%, #388E3C 100%);
    color: #fff;
    padding: 40px 28px;
    display: flex;
    flex-direction: column;
    min-height: 100vh;
}

.epw-logo {
    font-size: 1.8rem;
    font-weight: 800;
    margin-bottom: 4px;
    letter-spacing: -0.5px;
}

.epw-tagline {
    font-size: 0.85rem;
    opacity: 0.7;
    margin-bottom: 40px;
    text-transform: uppercase;
    letter-spacing: 1.5px;
}

.epw-steps-list {
    flex: 1;
    display: flex;
    flex-direction: column;
    gap: 8px;
}

.epw-step-item {
    display: flex;
    align-items: center;
    gap: 12px;
    padding: 12px 16px;
    border-radius: 10px;
    font-size: 0.92rem;
    opacity: 0.65;
    transition: all 0.2s;
    cursor: default;
}
.epw-step-item.active {
    background: rgba(255,255,255,0.2);
    opacity: 1;
    font-weight: 700;
}
.epw-step-item.done {
    opacity: 0.85;
}

.epw-step-num {
    width: 28px;
    height: 28px;
    border-radius: 50%;
    border: 2px solid rgba(255,255,255,0.5);
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 0.8rem;
    font-weight: 700;
    flex-shrink: 0;
}
.epw-step-item.active .epw-step-num { border-color: #fff; background: rgba(255,255,255,0.3); }
.epw-step-item.done .epw-step-num { background: #81C784; border-color: #81C784; }

.epw-progress-wrap {
    height: 6px;
    background: rgba(255,255,255,0.2);
    border-radius: 50px;
    margin: 32px 0 8px;
    overflow: hidden;
}
.epw-progress-bar {
    height: 100%;
    background: #A5D6A7;
    border-radius: 50px;
    transition: width 0.5s ease;
}
.epw-progress-label {
    font-size: 0.8rem;
    opacity: 0.7;
    text-align: center;
}

/* ========================
   MAIN CONTENT
   ======================== */
.epw-main {
    flex: 1;
    padding: 60px;
    overflow-y: auto;
}

.epw-step-content { max-width: 760px; }

.epw-step-content h1 {
    font-size: 2rem;
    font-weight: 800;
    color: #1B5E20;
    margin: 0 0 12px;
}

.epw-intro {
    font-size: 1.05rem;
    color: #555;
    margin-bottom: 36px;
    line-height: 1.6;
}

/* ========================
   PLUGIN CARDS
   ======================== */
.epw-plugins-list {
    display: flex;
    flex-direction: column;
    gap: 16px;
    margin-bottom: 36px;
}

.epw-plugin-card {
    display: flex;
    align-items: center;
    gap: 18px;
    background: #fff;
    border-radius: 14px;
    padding: 20px 24px;
    border: 2px solid #e8f5e9;
    box-shadow: 0 2px 12px rgba(0,0,0,0.04);
    transition: border-color 0.2s;
}
.epw-plugin-card.installed { border-color: #A5D6A7; background: #F1F8F1; }

.epw-plugin-icon { font-size: 2.2rem; flex-shrink: 0; }

.epw-plugin-info { flex: 1; }
.epw-plugin-info strong { font-size: 1.05rem; color: #1B5E20; }
.epw-plugin-info p { font-size: 0.9rem; color: #777; margin: 4px 0 0; }

.epw-badge {
    display: inline-block;
    background: #E8F5E9;
    color: #2E7D32;
    padding: 2px 10px;
    border-radius: 50px;
    font-size: 0.75rem;
    font-weight: 700;
    margin-left: 8px;
    text-transform: uppercase;
    letter-spacing: 0.5px;
}
.epw-badge-blue { background: #E3F2FD; color: #1565C0; }

.epw-installed-badge {
    color: #2E7D32;
    font-weight: 700;
    font-size: 0.95rem;
}
.epw-pending-badge {
    color: #f57c00;
    font-size: 0.9rem;
}

/* ========================
   PAGES LIST
   ======================== */
.epw-pages-list {
    display: flex;
    flex-direction: column;
    gap: 12px;
    margin-bottom: 36px;
}
.epw-page-item {
    display: flex;
    align-items: center;
    gap: 16px;
    background: #fff;
    border-radius: 12px;
    padding: 16px 20px;
    border: 2px solid #eee;
}
.epw-page-icon { font-size: 1.5rem; }
.epw-page-info { flex: 1; }
.epw-page-info strong { color: #333; }
.epw-page-info p { font-size: 0.88rem; color: #999; margin: 2px 0 0; }

/* ========================
   BUTTONS
   ======================== */
.epw-btn {
    display: inline-block;
    padding: 12px 28px;
    border-radius: 50px;
    border: none;
    cursor: pointer;
    font-size: 0.95rem;
    font-weight: 700;
    text-decoration: none;
    transition: all 0.2s;
    line-height: 1;
}
.epw-btn-primary {
    background: #4CAF50;
    color: #fff !important;
}
.epw-btn-primary:hover {
    background: #2E7D32;
    transform: translateY(-2px);
    box-shadow: 0 6px 20px rgba(76,175,80,0.3);
}
.epw-btn-secondary {
    background: #f5f5f5;
    color: #555 !important;
    border: 2px solid #e0e0e0;
}
.epw-btn-secondary:hover { background: #e0e0e0; }

/* ========================
   NAVIGATION
   ======================== */
.epw-nav {
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-top: 40px;
    padding-top: 28px;
    border-top: 1px solid #eee;
}

/* ========================
   SETTINGS FORM
   ======================== */
.epw-settings-form { max-width: 520px; }
.epw-field {
    margin-bottom: 24px;
}
.epw-field label {
    display: block;
    font-weight: 600;
    color: #333;
    margin-bottom: 8px;
    font-size: 0.95rem;
}
.epw-field input, .epw-field select {
    width: 100%;
    padding: 12px 16px;
    border: 2px solid #e0e0e0;
    border-radius: 10px;
    font-size: 0.95rem;
    transition: border-color 0.2s;
    background: #fff;
}
.epw-field input:focus, .epw-field select:focus {
    outline: none;
    border-color: #4CAF50;
}
.epw-hint {
    display: block;
    font-size: 0.82rem;
    color: #999;
    margin-top: 6px;
}

/* ========================
   INFO BOX
   ======================== */
.epw-info-box {
    background: #E8F5E9;
    border: 1px solid #A5D6A7;
    border-radius: 12px;
    padding: 20px 24px;
    margin-bottom: 28px;
}
.epw-info-box h4 { margin: 0 0 12px; color: #2E7D32; }
.epw-info-box ol { padding-left: 20px; margin: 0; }
.epw-info-box li { margin-bottom: 6px; font-size: 0.92rem; color: #555; }
.epw-info-box a { color: #4CAF50; }

/* ========================
   NOTICE
   ======================== */
.epw-notice {
    padding: 14px 20px;
    border-radius: 10px;
    margin-bottom: 24px;
    font-weight: 600;
}
.epw-notice-success { background: #E8F5E9; color: #2E7D32; border: 1px solid #A5D6A7; }
.epw-notice-error   { background: #FFEBEE; color: #c62828; border: 1px solid #FFCDD2; }

/* ========================
   LOG BOX
   ======================== */
.epw-log {
    background: #1a1a2e;
    color: #81C784;
    border-radius: 10px;
    padding: 16px 20px;
    font-family: monospace;
    font-size: 0.88rem;
    margin: 20px 0;
    line-height: 1.8;
}

/* ========================
   DONE STEP
   ======================== */
.epw-done-step { text-align: center; }
.epw-success-icon { font-size: 5rem; margin-bottom: 20px; animation: bounce 0.8s ease; }
@keyframes bounce {
    0%   { transform: scale(0); }
    60%  { transform: scale(1.2); }
    100% { transform: scale(1); }
}
.epw-done-step h1 { font-size: 2.5rem; color: #1B5E20; margin-bottom: 12px; }
.epw-done-cards {
    display: grid;
    grid-template-columns: repeat(2, 1fr);
    gap: 16px;
    margin: 36px 0;
    text-align: left;
}
.epw-done-card {
    display: flex;
    flex-direction: column;
    gap: 6px;
    background: #fff;
    border-radius: 14px;
    padding: 24px;
    border: 2px solid #E8F5E9;
    text-decoration: none;
    transition: all 0.2s;
}
.epw-done-card:hover {
    border-color: #4CAF50;
    transform: translateY(-4px);
    box-shadow: 0 8px 24px rgba(76,175,80,0.15);
}
.epw-done-card-icon { font-size: 2rem; }
.epw-done-card strong { color: #1B5E20; font-size: 1rem; }
.epw-done-card p { color: #777; font-size: 0.88rem; margin: 0; }
